@@ -4,7 +4,7 @@ r"""*Helper regexes for* ``sphobjinv``.
 Sphinx |objects.inv| files.
 
 **Author**
-    Brian Skinn (bskinn@alum.mit.edu)
+    Brian Skinn (brian.skinn@gmail.com)
 
 **File Created**
     5 Nov 2017
@@ -16,10 +16,14 @@ Sphinx |objects.inv| files.
     https://github.com/bskinn/sphobjinv
 
 **Documentation**
-    https://sphobjinv.readthedocs.io/en/latest
+    https://sphobjinv.readthedocs.io/en/stable
 
 **License**
-    The MIT License; see |license_txt|_ for full license terms
+    Code: `MIT License`_
+
+    Docs & Docstrings: |CC BY 4.0|_
+
+    See |license_txt|_ for full license terms.
 
 **Members**
 
@@ -70,7 +74,7 @@ ptn_data = rf"""
     \s+                             # Dividing space
     (?P<{DF.Domain.value}>[^\s:]+)  # --> Domain
     :                               # Dividing colon
-    (?P<{DF.Role.value}>[^\s:]+)    # --> Role
+    (?P<{DF.Role.value}>[^\s]+)     # --> Role
     \s+                             # Dividing space
     (?P<{DF.Priority.value}>-?\d+)  # --> Priority
     \s+?                            # Dividing space
